#pragma once

/*
 The play audio library is used to play audio in PC, it can be paly file format
is: A34, A34Pro, A66, A1600, A1800, A3600, A4800, A6400, A340640, S200, S320,
S530, S880, S4872 and so on. Of course, it need the correlative library support.
*/
//#topic Play Audio
//#topic.

//The status of play
enum E_PLAY_STATE
{
	ePlayStatus_Stopped,  	//Stopped 
	ePlayStatus_Paused,     //Paused  
	ePlayStatus_Running,    //Running 
	ePlayStatus_Init        //Initial 
};


#define		NORMAL_SPEED_RATE		1
#define		UNIT_SPEED_VALUE		0.2


//The result
enum E_AUDIO_RESULT				
{                               
	eOK = 0,                    //OK                 	
	eError,                     //Error              
	eFileFormatNotSupportError, //Format not support 
	eNotSupportFormat,          //Not support format 
};

//The declare of the call_back function's type
typedef int (WINAPI *PFN_CALLBACK)(LPARAM lParam,WPARAM wParam);

//The declare of the call_back function's model 
int WINAPI	GetStatus(
			LPARAM lParam,		//The state of the play
			WPARAM wParam		//One parameter you may be use,you can define it by yourself
			);

//I_PlayAudio interface
class I_PlayAudio
{
public:
	virtual bool			PlayAudio()		= 0;	//Play a audio file, eg.: *.a18, *.a16, *.a34, *.wav and so on.
	
	virtual bool			StopAudio()		= 0;	//Stop play.
	virtual bool			PauseAudio()	= 0;	//Pause play.
	virtual void			Release()		= 0;	//Release interface object.

	virtual HRESULT			SetVolume(LONG	lVolume) = 0;	//set volume
	virtual HRESULT			AddVolume(LONG lVolume) = 0;	//set volume up & down
	virtual HRESULT			SetMuteState(BOOL bMute) = 0;	//Set mute or unmute.
	virtual HRESULT			PlayNormalSpeed() = 0;
	virtual HRESULT			PlaySpeedUp() = 0;
	virtual HRESULT			PlaySpeedDown() = 0;

	virtual	E_AUDIO_RESULT	PlayAudioRealTime(
			LPCTSTR			ptszFileName
			) = 0;

	virtual	E_AUDIO_RESULT	StopAudioRealTime() = 0;

	virtual E_AUDIO_RESULT	Open(					//Open a audio file, eg.: *.a18, *.a16, *.a34, *.wav and so on.
			LPCTSTR			lpszFileName			//The audio file
			) = 0;

	virtual bool			GetState(
			PFN_CALLBACK	pfnCallBack,			//The pointer of the call_back function
			LPARAM			lParam					//One parameter you may be use
			) = 0;									//Get current state

	virtual bool			GetProgress(			//Get current progress
			float			&fPercent				//The current porgress percent
			) = 0;	

	virtual bool			GetTotalTime(			//Get the audio file total time
			int				&i32Total				//The total second
			) = 0;	

	virtual	bool			GetTotalTimeMS(			//Get the audio file total time
			int				&i32Total				//The total millisecond
			) = 0;

	virtual bool			GetCurPos(				//Get the audio file current time
			int				&i32Position			//The current second
			) = 0;	

	virtual bool			GetCurPosMS(				//Get the audio file current time
			int				&i32Position			//The current millisecond
			) = 0;

};

extern "C" HRESULT GetPlayAudio(	//Get the I_PlayAudio interface
I_PlayAudio **piPlayAudio);			//Return the I_PlayAudio interface

extern "C" typedef HRESULT (WINAPI *PFN_CreatePlayAudio)(I_PlayAudio **piPlayAudio);


